@@ -37,13 +37,14 @@ use std::ops::Deref;
 /// # };
 /// ```
 ///
-/// If the query string cannot be parsed it will reject the request with a `400
-/// Bad Request` response.
+/// If the query string cannot be parsed it will reject the request with a `422
+/// Unprocessable Entity` response.
 ///
 /// For handling values being empty vs missing see the (query-params-with-empty-strings)[example]
 /// example.
 ///
 /// [example]: https://github.com/tokio-rs/axum/blob/main/examples/query-params-with-empty-strings/src/main.rs
+#[cfg_attr(docsrs, doc(cfg(feature = "query")))]
 #[derive(Debug, Clone, Copy, Default)]
 pub struct Query<T>(pub T);
 
