@@ -960,7 +960,10 @@ where
 
 use crate::routing::future::RouteFuture;
 
-impl<B, E> Service<Request<B>> for MethodRouter<B, E> {
+impl<B, E> Service<Request<B>> for MethodRouter<B, E>
+where
+    B: HttpBody,
+{
     type Response = Response;
     type Error = E;
     type Future = RouteFuture<B, E>;
@@ -980,7 +983,7 @@ impl<B, E> Service<Request<B>> for MethodRouter<B, E> {
             ) => {
                 if $method == Method::$method_variant {
                     if let Some(svc) = $svc {
-                        return RouteFuture::new(svc.0.clone().oneshot($req))
+                        return RouteFuture::from_future(svc.oneshot_inner($req))
                             .strip_body($method == Method::HEAD);
                     }
                 }
@@ -1014,13 +1017,12 @@ impl<B, E> Service<Request<B>> for MethodRouter<B, E> {
         call!(req, method, DELETE, delete);
         call!(req, method, TRACE, trace);
 
-        let future =
-            match fallback {
-                Fallback::Default(fallback) => RouteFuture::new(fallback.0.clone().oneshot(req))
-                    .strip_body(method == Method::HEAD),
-                Fallback::Custom(fallback) => RouteFuture::new(fallback.0.clone().oneshot(req))
-                    .strip_body(method == Method::HEAD),
-            };
+        let future = match fallback {
+            Fallback::Default(fallback) => RouteFuture::from_future(fallback.oneshot_inner(req))
+                .strip_body(method == Method::HEAD),
+            Fallback::Custom(fallback) => RouteFuture::from_future(fallback.oneshot_inner(req))
+                .strip_body(method == Method::HEAD),
+        };
 
         match allow_header {
             AllowHeader::None => future.allow_header(Bytes::new()),
@@ -1200,10 +1202,9 @@ mod tests {
             if method == Method::POST {
                 "OK".into_response()
             } else {
-                let headers = crate::response::Headers([(ALLOW, "GET,POST")]);
                 (
                     StatusCode::METHOD_NOT_ALLOWED,
-                    headers,
+                    [(ALLOW, "GET,POST")],
                     "Method not allowed",
                 )
                     .into_response()
